@@ -1,9 +1,6 @@
 package nodegroup
 
 import (
-	"time"
-
-	"github.com/aws/aws-sdk-go/aws/request"
 	"k8s.io/client-go/kubernetes"
 
 	"github.com/weaveworks/eksctl/pkg/accessentry"
@@ -11,7 +8,6 @@ import (
 	"github.com/weaveworks/eksctl/pkg/cfn/builder"
 	"github.com/weaveworks/eksctl/pkg/cfn/manager"
 	"github.com/weaveworks/eksctl/pkg/eks"
-	"github.com/weaveworks/eksctl/pkg/utils/waiters"
 )
 
 type Manager struct {
@@ -19,14 +15,11 @@ type Manager struct {
 	ctl                   *eks.ClusterProvider
 	cfg                   *api.ClusterConfig
 	clientSet             kubernetes.Interface
-	wait                  WaitFunc
 	instanceSelector      eks.InstanceSelector
 	launchTemplateFetcher *builder.LaunchTemplateFetcher
 	accessEntry           *accessentry.Service
 }
 
-type WaitFunc func(name, msg string, acceptors []request.WaiterAcceptor, newRequest func() *request.Request, waitTimeout time.Duration, troubleshoot func(string) error) error
-
 // New creates a new manager.
 func New(cfg *api.ClusterConfig, ctl *eks.ClusterProvider, clientSet kubernetes.Interface, instanceSelector eks.InstanceSelector) *Manager {
 	return &Manager{
@@ -34,7 +27,6 @@ func New(cfg *api.ClusterConfig, ctl *eks.ClusterProvider, clientSet kubernetes.
 		ctl:                   ctl,
 		cfg:                   cfg,
 		clientSet:             clientSet,
-		wait:                  waiters.Wait,
 		instanceSelector:      instanceSelector,
 		launchTemplateFetcher: builder.NewLaunchTemplateFetcher(ctl.AWSProvider.EC2()),
 		accessEntry: &accessentry.Service{
