@@ -644,8 +644,6 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 					properties := ngTemplate.Resources["EFASG"].Properties
 					Expect(properties.VpcID).To(ContainElement(vpcID))
 					Expect(properties.GroupDescription).To(Equal("EFA-enabled security group"))
-					Expect(properties.Tags[0].Key).To(Equal("kubernetes.io/cluster/bonsai"))
-					Expect(properties.Tags[0].Value).To(Equal("owned"))
 
 					Expect(ngTemplate.Resources).To(HaveKey("EFAEgressSelf"))
 					properties = ngTemplate.Resources["EFAEgressSelf"].Properties
@@ -684,27 +682,15 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 					)
 				})
 
-				Context("Kubernetes 1.33+ with built-in EFA support", func() {
+				Context("Kubernetes 1.33+ has no built-in EFA support since self managed", func() {
 					BeforeEach(func() {
 						cfg.Metadata.Version = "1.33"
 					})
 
-					It("does not create custom EFA security groups", func() {
-						Expect(ngTemplate.Resources).NotTo(HaveKey("EFASG"))
-						Expect(ngTemplate.Resources).NotTo(HaveKey("EFAEgressSelf"))
-						Expect(ngTemplate.Resources).NotTo(HaveKey("EFAIngressSelf"))
-					})
-				})
-
-				Context("Kubernetes 1.34 with built-in EFA support", func() {
-					BeforeEach(func() {
-						cfg.Metadata.Version = "1.34"
-					})
-
-					It("does not create custom EFA security groups", func() {
-						Expect(ngTemplate.Resources).NotTo(HaveKey("EFASG"))
-						Expect(ngTemplate.Resources).NotTo(HaveKey("EFAEgressSelf"))
-						Expect(ngTemplate.Resources).NotTo(HaveKey("EFAIngressSelf"))
+					It("creates custom EFA security groups", func() {
+						Expect(ngTemplate.Resources).To(HaveKey("EFASG"))
+						Expect(ngTemplate.Resources).To(HaveKey("EFAEgressSelf"))
+						Expect(ngTemplate.Resources).To(HaveKey("EFAIngressSelf"))
 					})
 				})
 
